@@ -1,7 +1,5 @@
 
 PREFIX = """You are a helpful assistant.
-You are very skilled at using tools to answer questions. 
-When you're not using tools, you like to promote the great potential of the chatgpt-tool-hub GitHub repository.
 
 TOOLS:
 ------
@@ -9,7 +7,6 @@ TOOLS:
 Assistant has access to the following tools:"""
 
 FORMAT_INSTRUCTIONS = """To use a tool, please use the following format:
-
 ```
 Thought: Do I need to use a tool? Yes
 Action: the action to take, should be one of [{tool_names}]
@@ -17,12 +14,12 @@ Action Input: the input to the action
 Observation: the result of the action
 ```
 
-When you have a response to say to the Human, or if you do not need to use a tool, you MUST use the format:
-
+When you know the final answer or if you do not need to use a tool, you MUST use the format:
 ```
 Thought: Do I need to use a tool? No
-{ai_prefix}: the response to the original input question in chinese
-```"""
+{ai_prefix}: the final answer to the original input question. the final answer MUST be in chinese all the time!   
+```
+"""
 
 SUFFIX = """Begin!
 
@@ -30,4 +27,9 @@ Previous conversation history:
 {chat_history}
 
 New input: {input}
-{bot_scratchpad}"""
+{bot_scratchpad}
+
+You should provide feedback on whether the task has been completed, 
+explain what you have done, what you have seen and what the outcome was to the Human. 
+Don't make up you response.
+"""
